@@ -119,6 +119,9 @@ pub struct MiniserveConfig {
     /// If false, creation of zip archives is disabled
     pub zip_enabled: bool,
 
+    /// Enable  compress response
+    pub compress_response: bool,
+
     /// If enabled, directories are listed first
     pub dirs_first: bool,
 
@@ -143,6 +146,9 @@ pub struct MiniserveConfig {
     /// If enabled, render the readme from the current directory
     pub readme: bool,
 
+    /// If enabled, indexing is disabled.
+    pub disable_indexing: bool,
+
     /// If set, use provided rustls config for TLS
     #[cfg(feature = "tls")]
     pub tls_rustls_config: Option<rustls::ServerConfig>,
@@ -263,9 +269,9 @@ impl MiniserveConfig {
             .map(|v| {
                 v.iter()
                     .map(|p| {
-                        sanitize_path(p, false)
+                        sanitize_path(p, args.hidden)
                             .map(|p| p.display().to_string().replace('\\', "/"))
-                            .ok_or(anyhow!("Illegal path {p:?}: upward traversal not allowed"))
+                            .ok_or(anyhow!("Illegal path {p:?}"))
                     })
                     .collect()
             })
@@ -308,7 +314,9 @@ impl MiniserveConfig {
             hide_theme_selector: args.hide_theme_selector,
             show_wget_footer: args.show_wget_footer,
             readme: args.readme,
+            disable_indexing: args.disable_indexing,
             tls_rustls_config: tls_rustls_server_config,
+            compress_response: args.compress_response,
         })
     }
 }
